'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pluginScaffolderBackend = require('@backstage/plugin-scaffolder-backend');
var fsPromises = require('fs/promises');
var fs = require('fs');
var path = require('path');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n["default"] = e;
  return Object.freeze(n);
}

var fsPromises__namespace = /*#__PURE__*/_interopNamespace(fsPromises);
var fs__namespace = /*#__PURE__*/_interopNamespace(fs);
var path__default = /*#__PURE__*/_interopDefaultLegacy(path);

const gitCloneAction = () => {
  return pluginScaffolderBackend.createTemplateAction({
    id: "git:clone",
    schema: {
      input: {
        required: ["repoUrl"],
        type: "object",
        properties: {
          repoUrl: {
            type: "string",
            title: "Repository URL",
            description: "The repository to clone"
          },
          args: {
            type: "array",
            items: {
              type: "string"
            },
            title: "Arguments to pass to the command"
          }
        }
      }
    },
    async handler(ctx) {
      ctx.logger.info(`repoUrl: ${ctx.input.repoUrl}`);
      const splitRepoUrl = ctx.input.repoUrl.split("/");
      const fileName = splitRepoUrl[splitRepoUrl.length - 1];
      if (fs__namespace.existsSync(fileName)) {
        ctx.logger.info(`File ${fileName} exists in workspace, removing...`);
        await fsPromises__namespace.rm(fileName, { recursive: true, force: true });
      }
      let args = ["clone", ctx.input.repoUrl];
      if (ctx.input.args && ctx.input.args.length) {
        args = [...args, ...ctx.input.args];
      }
      await pluginScaffolderBackend.executeShellCommand({
        command: "git",
        args,
        logStream: ctx.logStream,
        options: {
          cwd: ctx.workspacePath
        }
      });
      ctx.logger.info(`Finished cloning ${ctx.input.repoUrl}`);
    }
  });
};

const gitAction = () => {
  return pluginScaffolderBackend.createTemplateAction({
    id: "git",
    schema: {
      input: {
        required: ["command", "workingDirectory"],
        type: "object",
        properties: {
          command: {
            type: "string",
            title: "Command",
            description: "The git command to run"
          },
          workingDirectory: {
            type: "string",
            title: "Working Directory",
            description: "Working directory within the scaffolder workspace to execute the command in"
          },
          args: {
            type: "array",
            items: {
              type: "string"
            },
            title: "Arguments to pass to the command"
          }
        }
      }
    },
    async handler(ctx) {
      let args = [ctx.input.command];
      if (ctx.input.args && ctx.input.args.length) {
        args = [...args, ...ctx.input.args];
      }
      await pluginScaffolderBackend.executeShellCommand({
        command: "git",
        args,
        logStream: ctx.logStream,
        options: {
          cwd: path__default["default"].resolve(ctx.workspacePath, ctx.input.workingDirectory)
        }
      });
      ctx.logger.info(`Finished executing git ${ctx.input.command}`);
    }
  });
};

exports.gitAction = gitAction;
exports.gitCloneAction = gitCloneAction;
//# sourceMappingURL=index.cjs.js.map
